@@ -38,6 +38,7 @@
 #include "gdl-dock-item.h"
 #include "gdl-dock-item-grip.h"
 #include "gdl-dock-item-button-image.h"
+#include "gdl-switcher.h"
 #include "gdl-tools.h"
 
 #define ALIGN_BORDER 5
@@ -258,9 +259,33 @@ static void
 gdl_dock_item_grip_iconify_clicked (GtkWidget       *widget,
                                     GdlDockItemGrip *grip)
 {
+    GtkWidget *parent;
+    
     g_return_if_fail (grip->item != NULL);
 
-    gdl_dock_item_iconify_item (grip->item);
+    parent = gtk_widget_get_parent (GTK_WIDGET (grip->item));
+    if (GDL_IS_SWITCHER (parent))
+    {
+        /* Note: We can not use gtk_container_foreach (parent) here because
+         * during iconificatoin, the internal children changes in parent.
+         * Instead we keep a list of items to iconify and iconify them
+         * one by one.
+         */
+        GList *node;
+        GList *items =
+            gtk_container_get_children (GTK_CONTAINER (parent));
+        for (node = items; node != NULL; node = node->next)
+        {
+            GdlDockItem *item = GDL_DOCK_ITEM (node->data);
+            if (!GDL_DOCK_ITEM_CANT_ICONIFY (item))
+                gdl_dock_item_iconify_item (item);
+        }
+        g_list_free (items);
+    }
+    else
+    {
+        gdl_dock_item_iconify_item (grip->item);
+    }
     
     /* Workaround to unhighlight the iconify button. */
     GTK_BUTTON (grip->_priv->iconify_button)->in_button = FALSE;
@@ -346,9 +371,14 @@ gdl_dock_item_grip_realize (GtkWidget *widget)
                                              &attributes, (GDK_WA_X | GDK_WA_Y));
 
         gdk_window_set_user_data (grip->title_window, grip);
-        widget->window = grip->title_window;
+
+        /* Unref the ref from parent realize for NO_WINDOW */
+        g_object_unref (widget->window);
+
+        /* Need to ref widget->window, because parent unrealize unrefs it */
+        widget->window = g_object_ref (grip->title_window);
         GTK_WIDGET_UNSET_FLAGS(widget, GTK_NO_WINDOW);
-        
+
         /* Unset the background so as to make the colour match the parent window */
         gtk_widget_modify_bg(widget, GTK_STATE_NORMAL, NULL);
  
